@@ -13,6 +13,10 @@ export function getNewDashboardPhrase() {
   return t('search.dashboard-actions.new-dashboard', 'New dashboard');
 }
 
+export function getNewTemplateDashboardPhrase() {
+  return t('search.dashboard-actions.new-template-dashboard', 'Dashboard from template');
+}
+
 export function getNewFolderPhrase() {
   return t('search.dashboard-actions.new-folder', 'New folder');
 }
